@@ -1,5 +1,5 @@
 from __future__ import annotations
-from typing import Dict, Tuple, Optional, Any
+from typing import List, Dict, Tuple, Optional, Any
 import boto3
 import botocore.exceptions
 import boto3.dynamodb.conditions
@@ -30,6 +30,7 @@ class InternalError(Exception):
 class DB:
 
     def __init__(self, name: str, logger):
+        self._name = name
         self._table = boto3.resource("dynamodb").Table(name)
         self._logger = logger
         self._to_put = []
@@ -54,6 +55,15 @@ class DB:
         except botocore.exceptions.ClientError as e:
             raise InternalError() from e
 
+    def get_bulk(self, keys: List[ItemKey]):
+        try:
+            response = self._table.meta.client.batch_get_item(RequestItems={
+                self._name: {"Keys": [key.as_dynamodb_key() for key in keys]}
+            })
+            return response["Responses"][self._name]
+        except botocore.exceptions.ClientError as e:
+            raise InternalError() from e
+
     def stage_put(self, key: ItemKey, item: Dict, expect_if_item_exists: Dict = None):
         self._to_put.append((key, item, expect_if_item_exists))
 
@@ -215,6 +225,12 @@ class DBMock:
             DBMock.count_get_operations += 1
         return DBMock._table.get(self._key_for_table(key))
 
+    def get_bulk(self, keys: List[ItemKey]):
+        items = []
+        for key in keys:
+            items.append(DBMock._table.get(self._key_for_table(key)))
+        return items
+
     def stage_put(self, key: ItemKey, item: Dict, expect_if_item_exists: Dict = None):
         self._to_put.append((key, item, expect_if_item_exists))
 
